
# q-expansion of newform 50.18.a.c, downloaded from the LMFDB on 06 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 50
weight = 18
poly_data = [-735, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-240, 480], 1]]

hecke_ring_character_values = None
aps_data = [[-256, 0], [-8814, -1], [0, 0], [-13842098, -117], [32257632, -90882], [-1447919234, 74988], [-790106298, -1394748], [22106856380, -7161912], [-243774891414, 23366889], [1993657431750, -2589624], [-2746130669668, 48426966], [31357643818942, 503271432], [11705738638662, 5025537684], [62428461595546, 2880330687], [92973306061782, -4923046557], [-179669890323834, 25138319508], [451089585180300, -65066242428], [-782211459483838, -93596587488], [2919869465527342, 31577428989], [-33794280217068, 232972538742], [-1766695349792834, 214621625988], [9501328198276040, -349601077692], [-10837543987559094, 1106830681155], [-48749761096111110, 1388020676040], [-49944968927693378, 958545051660], [17420123544422982, 11283338619864], [-97616936224835294, -8746003552995], [59792446560384822, 10389339993789], [-97679734731611710, 17784241762104], [-353873825721889914, 6456380842584], [-419651158094801138, 523473075279], [-52708659932320608, 11243531157714], [294265386673514862, -143194524247152], [-1161573230796374020, 118193183862732], [2083050558809960250, 53762130401400], [-339522739764761548, 250853605294230], [-969661325763549098, 445275719143128], [7526704981746927706, -242301810141405], [1471477484651802942, -112626170520021], [-6073636939136087994, -700409799433080], [1786798333327443060, -1266748385840676], [-1512799242189465418, 1217276246757456], [14828448756158853972, 2512252900848042], [2087740532645639206, 924852487555620], [-43564667445729809298, 703214118739044], [4388118374826717320, 181315519854336], [-35173327961628220528, -741535050976110], [-33868921243402011974, -5292407150454699], [84240012808017183222, -2721155294054943], [-81130853857004084530, 5331116395251072], [27298997320413215046, 15949859642593452], [-180606156267603399000, -2285143277640012], [-203619296953839431218, -7042393822903740], [281192151997935497952, 6184777730994630], [-227037336235952356218, -4371263719348968], [-383952210633526611774, 14961793330559781], [-134784063399962674350, 29067180369933744], [-26872880434134188428, 33626215806714234], [322077746249822002342, -49991027399727192], [-50404701318986458938, -55856219303320740], [-411133436068788006974, 54618567198509691], [30496265249864755806, -21114350577445680], [-1002508420646813061458, -105188160456320715], [175979333027478710892, 15925078872463986], [1068433263229308033046, -113807412038863368], [930384511376329739142, -38159027575431876], [92195988729365064872, 19782488249664858], [-2098764532053749613698, -281698311850497720], [1232770713637630217742, 219592309716437841], [1562248107001193275190, -156856446157881168], [5921363764473899673966, -159367877915466312], [-733377407165720137320, -647353462682500704], [-3582980127401624316698, 63357785085838707], [-2508368764308503112794, 401387222034430200], [-5974760482172637991900, 68041244570542056], [6262185754172588047146, 107230073666578317], [-12152023838590487974470, -166610600525001168], [8171725465564206044542, 237208900258752876], [9115247334678110429922, -111468997110039264], [-2080706124376314601570, -293212914788596644], [-4546203909519463694940, 519135004051311132], [1281915603293070398042, 180113099809571640], [36838328978071595095812, 52373706767122770], [4402911226712249965246, -1315842004033812468], [-28324392333234374322040, 43319840402991456], [10180756558414265085066, 1046105199860571423], [32124756934143549760710, 95062758861875508], [12416869155325037098342, -1990838824024803840], [26730740320896911347422, -3171901111106793480], [26917140730706782170466, 2419477309131079113], [-47266457536822191313458, 192862676062722069], [31359960587873924378280, -4778128950975123660], [38856940080529190826742, 1725917885611308207], [12962789992392715126752, 3012789096202206006], [83106821459842001845820, 4914244866172324176], [21153286353234925322946, 4446584353580965317], [102694970692598507955270, 2698429346955193248], [-29022106861007509345158, 16149824138078058240], [-37865353273921273771454, -3857884592910792813], [-62150077445787243369778, 14261774033995037352], [-16663646367549809021738, 2930861822243576337], [-144242591025421433842338, 8706405735586856376], [1720336003153097482146, 5029917671402354367], [-10031187553613329523490, 22058183916101682252], [222626507855242834701992, -10975110312431924550], [-111217871585976784012778, 4801601003378777712], [446204645870999799932982, 1956417898742704989], [371403696805913080214766, -4250569962781664352], [-284608875796648637373120, -9106417351645522236], [-252913997487808014616138, 5969721347944889868], [105325886354685557092582, 33312639337507154547], [-632101167833008220570114, -11419163839651816836], [228674080346519877627462, -13885466336026906500], [-628765953806640973972780, -7357547841898200480], [-272494361407727134623868, -18770949302435147394], [721800640046975645841582, 13387822088833923300], [138671919770793200255746, -76228429800659991273], [201541183857077305543782, 90124366644341531703], [-90755101145034659937834, -279869235396118092], [-499333710006215483824860, 4006606216172208084], [777737732755982573225642, 46464395604364906416], [-495531297970547301934994, 33476317819826895540], [455920143652910357710062, 34384959287411711724], [872405353187950168631226, -89331608422783573569], [-1674386851743830750930968, -12466819108731082050], [531001997238583150924962, -22858182575396677512], [1620698059716315193783070, 127078089952428519048], [303492639577458546577320, 2238570632665357380], [-3366074486202897885085058, 1560591962920254843], [877307396212902657027286, 247819549776922177344], [-498267690346192448044780, -242068440259327054716], [-3161661955231425753529494, 101454160084640373465], [-417266532995255552218468, -331436697778205790426], [265622814246568098404182, -188714997628703286768], [-1613136391906203354975318, -153815038146459382752], [-2715201422774758272243070, -38818307776525781112], [-5098828866926827863824994, 22572015749179980660], [109918395163089659403862, -77348151682488052407], [2960940153674541633103062, -88470572938808679468], [625174918527895202395770, -105188615659522605312], [-2386887411791266331249968, 319184287009771054518], [-2153606122996371435240438, 517393159050776500296], [538177541442350985009226, 567592293149409262761], [-8171710135315304940346098, 123240034498232421441], [-1204178863149962090519230, -700086023123597517888], [-4761023874179628222822000, 208047056463718608348], [-3578165541375325121714, 352538891093412455364], [11751642819860443056867822, 231033435320814160104], [-2565123146200117820975620, 764521967071356224076], [-631150483343905858548054, -45236559151246282443], [7053087493234200356092582, -481471884023818466160], [-7276930823072989250723538, -585046043839894009860], [-3723510368088158593031294, -1387152871515708421185], [13807913300025887427831102, -28723402360210867605], [-1367313868479960498910178, 1823097481051173577569], [-2309571050483173637900628, 3848119702462784790], [8963612535134770132971440, -1577359421399857900644], [4816734425068925634631830, -612308304986935066380], [-11756349651961673058553898, -503516870412484903020], [9026745523101419405593902, -1241197751741728816224], [8595540501807629186798622, -1076779111747656092355], [-17365045230672335578738554, 749801771118597137472], [-29529535502973623985707738, -174619250782675733745], [16026816080557008863315592, 1667814589847542102650], [22930681550513475197962542, 72436739582091159828], [1126901695237821528775746, 1331430721168965364557], [-27218034674623566415095268, -835674456316615044930], [-3500836172629102348818458, 2773623362365996610076], [30699438349860034443607730, 174083523112321784856], [-15384448975273209462183954, -1535945711592090567348], [-30220583984197091636392860, 60664540501058605416], [-34665356543163478461177778, -953077011256788077376], [43230239900456914634853612, 682930891947866453370], [-18325903197271219273678274, 1094674208319846633996], [10156284601180888729963760, 5076607734720175582656], [37165496549221158409314090, 2007338698437537049272], [-17522295897207253825363288, -2718517611850531440102], [57319209795555285686647542, 3473557792186240616256], [57786994646712721570076026, 753542108197979848281], [25484840472730881147487250, -2692444310972645576256], [-22956798176531150871184538, 400083498866856706443], [17210971604937929752571472, -6198277975427924656038], [-10521126146473015088384234, 6085953524816845390188], [66860337608055150589405662, -1398127978802851789788], [-13296691992352930278351654, -3400275520919076337323], [26867540723458366943050590, 4720146408889097581944], [-19140304101510053420624018, 724586148360775682856], [-115884148866078905509417214, 628551484606785207159], [118020415085830725202204670, -2544940121315758247988], [41082440415381649091252652, 1957938635726857174950], [-25296700561139300066228714, -8853288099714635712336], [16523327014848053046617946, -6767014010232742520913], [-120567398305279235709248968, 2499040366947677242422], [-49148369054658470426678238, 7204970171069460388080], [-132537226934819924104483338, 282958154755815038193], [100616982170184035505858246, 4882450656658279536612], [3580200186934280771101262, -11523666073564226118132], [-290237172734566758016288154, -280578988930189550868], [98576956370983694819069982, -5228608926896318265984], [101849407051505853420951186, 6975473994329340997989], [95880852058321536935888070, -13446111719575023895368], [-15204844218407774471625148, 18617727210899413581162], [-138198166232275693030175978, -1339792034023922298084], [33139924249366909891001810, -6823302692131717584192], [-327831644948263554783515460, 5486625680334958138644], [-214426826852566117690519098, -6106747526881627276944], [-100269818603325265239637600, 19914640307526594274776], [59035448322055628182605426, 6613879988642179762431], [46683256225766671989217530, -1075672957324870994328], [-182023749168652800468117928, 1858568722825915254402], [-277061838171448090173932378, 7581578745245637786300], [-77978677573787886868228758, 11090696904096137557272], [205209438203844113531085346, 3306692355097775670477], [127712261983331369519180982, 18517056292935496604277], [122744794987792135024776720, -7736603393370062772540], [-9648469949643975997019338, -31785481741137877069164], [291124815640353138980784862, 7512299263699419706479], [-190609624597823498759790318, -19788154145828522464032], [-340813697928960863167164738, -32782535869917992698125], [331528534061063641657515246, -15708619121090069965068], [275158049444960057785799642, 32816628964057672638864], [-327396047615992784572590880, -54414501082784051846724], [208561182825066027028593810, 11505973310563068011880], [416407286367344523947360146, 21517745044487260097097], [671583318580914376763931942, 23312291293327060675233], [391073201665949668311755690, -22894130072761250815872], [-402072349048850218657880994, -60963175572090340342500], [1324008116648215219728000, -28659768804350828796312], [451734244616036564110152742, -27559374338749902148449], [896849611999898609384665992, 38533709767879546521642], [330667389402650379081162286, -72077105892176437884876], [175333969793250680121749900, -20894245850691079026408], [-315976476595216493287972828, 12551549927643503163234], [37053087723810017042232822, 22209702516216820485468], [74015429673383335566395026, -50579550510384474612549], [-1183016908080877038490570578, -38051573723464827031209], [-1735586255795597827104290170, -7380710062487365729788], [764623736521289608326451926, 71121266147562909676956], [-206004939202502772620189820, 63340104966267429618624], [-165004254291407655842717028, 88473848157336684243330], [-908419699775171239679423334, -17094428733013575426837], [-410954257662271983532375648, -40890702482481356517258], [379319087630370415936248826, 50914830883427623988721], [-102181538162257285325507530, 153676779542950496176656], [-816305859037596162504169314, -10712372231635015583016], [-275008089340095908286081000, -78205196512966099710168], [468200627626332494257187422, -18372401116989703054857], [-272592579114542163472699368, -14692460838130871327178], [384905496041860863720434300, 107161981165505213501076], [-1100702907197180701969293534, 11174377502626926938793], [-15800376947844430759755698, 140287920435292008796524], [-1544491946573064867370876398, -111674457537431784294240], [1233657964650276164398280982, -151671630385086565452273], [1820788902131928658205628110, -98165887307402893738020], [-999112229852883204523940154, -99073852278782014534608], [-1016257537170663888613025460, -108599753728573488591984], [2145730789348913569077322502, 82878725062713393331128], [1458772233243500675841058462, -25158622638274457516631], [-290032860380760566818207338, -205838593718403381999192], [-411213670129472773192841018, -89041862055696425425728], [-1405997069048353637037604214, -209776328719413317759691], [1075653938645366112311770182, -42211025397716151213639], [-218875315365048884709213490, -104103991588556724025248], [457692320676824068971151246, 157772509486838932575312], [-1032199138982247612253156458, 23804037465223739776956], [-488073703504708187939135380, 93860909790455327273856], [-2879789965400248269203395770, -174993326044604563482144], [419442312095142625638034602, -339348652310263800888432], [2946806618224668397838214346, -139197566201141074347873], [2442936221867883908132803086, 206620765456641755539464], [1623949453613765714511950462, -305745304780959352389936], [3626160698036370916377184942, -15178098838058191036539], [-2080806442453564396763909594, 201614653217248924406220], [-5152124691216870746497319440, -4280969073334135782960], [2528607066794307719741437462, -291845284502267850854976], [-5162659843083057930763571414, -144707403352229262652671], [-4564296496862153009398818978, -86660913247547379697719], [-2240831964808543438030428490, 202080724307449159004136], [4087582822059186146046047462, 364075409542918849277868], [-664722836882555435117549328, -133979061072485835481590], [-630411989427622604421709734, 136594899798480654630813], [-4306272000495219619312437028, -274853428724926678470102], [-6566923998694168588587836058, 98672812958344991636871], [7192473439731554991691304582, 6861950030235208046688], [7483967054626113725029296742, 347508600176315239230069], [5787442258689105409865524092, -15200142899342627372490], [-4128822647008435186892430554, -563444018306801360502588], [-2761459947650229421392288738, -665005979935247378736276], [-1815568569646716938538638320, -444020112353349556879140], [-765431387342155658640660330, 5261754572560352883924], [901429895925577072085605842, -404697866036747800699368], [-5208224572966604248688295738, 110305821042498113216001], [3815366602069574467406324526, 331779951362568691915596], [-1401265698802421269657523568, -348565174131716630551314], [-8307867202964643036907572314, -96637930131145564797696], [-8273894119652100495948737070, -414617614831880219504376], [7132714312994714885127974252, 466704864812984444122950], [7904989085950571712893099406, 261777859224514012571760], [8297017455586428635384637060, 81044720611257204077904], [-1299004345960154841163719458, 526954409214017624616357], [-1007523333815426953148006834, 1036059321429064799398368], [10674875652297025375405136502, -83879241065970484189176], [6810304556765576494641365480, -221023742565028287566196], [10776172887687816733909292706, -17510159111880555849825], [-10155505363314130405184412928, 158549177761952938244550], [4657869083946084457511202622, 396571898840828871769668], [-6507468638559109897421146578, 928405850782124123367417], [3311289832079701768525579190, 809722809332494643699208], [-10478070919984208834271323880, 429081082315357392147384], [7844684206277800009277070526, -559050561794589147338184], [12279076814180016669311116026, 1131502466142498884469741], [5867215450882913553742914270, 687704479605019657570320], [-7904568981529027508933276958, 611911152436611345019344], [3658568539973364986974512226, 156970967451086280152151], [4598285494202544441307269102, -949769416474130981251485], [15251191666080365730563260490, 427700371724344005561720], [-6325947844398715958123763300, -940387614893289796774680], [21687960749726009596224287532, 772182901552544549206398], [-20250721954225189168330720154, -802310043511517274727848], [-18266265581121928213361252970, 1374023338406667140477940], [23010540194523553028434520552, -1028050636901490967224258], [6648528561402634294964962942, 110418816056003306939952], [1699031525868980815141568802, -2230294139137087112604384], [-16664046414245918134580196974, 445714677624234167727561], [-17198768981929932883332762594, -1357751883652977173302440], [7520302420752297021079932062, -36692156325898755953388], [-16365130876354155805573495540, 936119505862361253850704], [-12393217164134457262992305894, 1124610845297923003863735], [11162475711991269709899284742, -1665215481767947865689005], [3864181066735670721773079606, 3163847998891364510786460], [-22333192057141120802811474958, 890943026336287496891640], [-19714332657351771138500026218, -1208515384948907790128736], [-180604388527519784448035560, -462404220099736503319380], [9017732074503137130250484346, -1482205821300712769311053], [-7245537990788725161031903408, -33678250182722097510498], [-40728875609224740061664403018, -227637540853668217359819], [24605472018411048584019188210, -2256161405469559817410008], [27035391953096799471761569446, -1498956708236617179750528], [3756519727256690916725793302, -461050177782067644775428], [8247873481467496393877769742, -1117712690955298603231713], [4054745576943328235795462206, -2545908799741933219221600], [-26772463971271057394043951018, 2048909771960564831199648], [-29833860094228189870549185270, -2520079888775776273303704], [18619222533073747165996220852, 2124354090501284264678574], [-25390382847836490436017279954, 429364494310558070513592], [22482021915202547261040368460, -2399830994842311554448624], [-9509392031189795233353269638, -4319756325595602796039776], [-13456656021049188293432814818, -3658384492479564450296607], [-20818092177593242764800495748, -458855918415793198403370], [17275828874558575179323433582, -1487911417162623145610028], [-14294319149369499662169683728, 1234983629499513360069474], [-58941494943736098490021918538, -594325007574917438001096], [-6013313995224638892621159438, 1464928738781461158612960], [2983468750434196048910087986, 2957116273758623535264009], [-42459057539931402394569777250, -4336315002259048869972192], [-4826449751333409507092031474, -4399336870979877653642604], [-54067512893556858841964355960, -3299112792966677533726068], [58233537431628659781131552472, 3901161852042847447067730], [1598514245347575727646443662, -496458989692214804865180], [-14028890777983686593039149254, 1485928048770622316374137], [-17586649294037390460879389258, 5913985578406558519938012], [21606898072930861495575029322, -2003414869682256688897248], [48074332092191075878785405702, 3278917086973294619494899], [-102862981943404745235801362340, -452081439988519694467500], [-80666454179378441570046013898, -638633975070933065772783], [-81785611595475778745381213834, -3836314428853978794788172], [-73920674941424056693253461218, 89372895024770581919940], [-25248881858396111425617647534, 1441561573014968880808173], [-28481448072347576799166788298, -1501197699663087673936572], [14473697963684672988293226192, -4610095772613363774782046], [82213409820207992762881950980, 1530755732147241654808272], [-7867953930786256739432647134, -3445089811869450920813127], [7932448973890774656369491610, 5906191425686815069142568], [-18119712227985767161356007468, -570132867296000984310666], [47671633883905187418858552142, 4957718003703054562735260], [-97412574614282572811182771380, -6813859552108034859110448], [115553152394140208644221877932, 213368674363267323278070], [-24296587902338571035668162514, 8542672314913650094562304], [13112450005246904854605914310, -3682660109625928852040700], [-70960563097271372024069001218, -6952058397938310089138424], [74430027465957098062909193262, 1821166257813938443414656], [-43359681530890987875193496754, -2982653697017171568643128], [61178593137707226704846195782, -3924630157321579442146857], [-99801600676188026645204094738, -5053561686515032931279664], [71863281755680292645649891260, -1685857181869881844578360], [-96359937823659299810571694614, 9248570638457670629552529], [133918121324841642596449085252, -347292224779692690189702], [-86834648301772161146156947058, 10860290184671758434411288], [153958635243344729346666147946, 289080541285766369603487], [97465799724860379158461769382, -212691846619978115213421], [-215264600592343260945590625610, 1796572693556923653813780], [12308772242400902176482145686, -12982769781146776106638776], [61300419836845838295511247580, -2278229122043355554347716], [192045183867215062989166178302, -684927703174169259179667], [3233571002900323477384989252, 18588771632222424290646054], [118738406666879228479640196526, -3984518433488268869679744], [27460375284193853515285317320, -13047954298548815912281740], [208651396309801719089531289210, 6643606500988153675864704], [140654929576930134244309757312, -1502982300509404470868050], [134542383410517677116074177162, -8364793186775837385842256], [-31601298583345577087825182990, 6089301949918050674559288], [41384883856688618964331190886, -12629583572471440294535316], [131033041510258058413079835622, 7556029362546194032316163], [-68896459436082206139845427858, 17433116785752414703273728], [46374231562239563578725831450, 3025239487236282618250848], [153160074600192196898838246452, 406451415125542501988406], [236015651855076270474956881222, 742398987764924491231620], [-48278432516020780669474776558, 150163482996983026744272], [52933256656934359563892228906, -6425104208052812654890845], [92516251744366878871238069700, -1135673781196549316958396], [37736365413958175791875054766, 14193634562854992904685688], [-19874429019203521643079608658, -20979279043824565843436088], [154965610467644256320080221666, -16020939485182761935462277], [39858067076845248519348270272, 7696322721721917878279346], [-33031097049357176176984206098, -9072475938519022811709612], [2248712548129170840764776062, -17654000825420396897620968], [-264273841225701983685052108320, -8338779917810376266629800], [310990002802401282008942971342, -12017654177712423130432413], [-41651788068519420163338731298, -19963294181684922507057396], [-183642307860045833911310093334, -7093034592947985437975727], [126458616710826724078016815650, -23921827911838633474544688], [-245172953010420974688335859458, -4030961074846899401513556], [-102363306512272595389726968618, 11158520762702491855726995], [-5946652751571628184474027460, 2494742131656975514699980], [35340936124739760577898444086, -35159068500606735513078816], [24054145129214761536812616102, 10395584554928556572435448], [-213650882923589666003612061534, 28447172092572615921795903], [85103029453802871948388506750, 17328593811495640443868044], [203056357348181023751071677512, -25993965859017760122195654], [-361592527422436816378186212120, 14000342174106941823646824]]
